% compactness() - evaluate compactness of component ROA map by
%                 using pair distance measurement (pdist() provided
%                 by matlab.
%
% Usage:
%    >> distdist = compactness(component_no,z_threshold,...
%                  dist_method);
%
% Inputs:
%    component_no - component number
%    z_threshold  - z value threshold for ROA maps
%    dist_method  - method to derive pair distance, options:
%                 - 'euclid'
%                 - 'seuclid'
%                 - 'cityblock'
%                 - 'mahal'
%                 - 'minkowski'
%
% output:
%    distdist - distribution of distance measurement
%
% Author: Jeng-Ren Duann, SCCN/INC/UCSD & CNL/Salk Inst., 2003-02-19
%
% See also: pdist(), gamfit(), gampdf()
%
% Note: 
%    - This function need to be launched under fmrlab with fmr
%    dataset loaded.
%    - pdist(), gamfit() and gampdf() functions need
%    matlab/statistics toolbox

% --
% Copyright (C) 2002 Jeng-Ren Duann, Salk Institute, duann@salk.edu
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2 of
% the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

% $Log: compactness.m,v $
% Revision 1.1  2003/02/06 19:09:56  duann
% Initial revision
function distdist=compactness(component_no,z_threshold,dist_method)
  
if nargin < 3,
  dist_method = 'euclid';
end
if nargin < 2,
  z_threshold = 1.5;
end

global FMRI

W = FMRI.icaweight * FMRI.icasphere;
u = W * FMRI.data;

activation = u(component_no,:);
activation = (activation - mean(activation)) / std(activation);

% find the coordinates of voxels which are with activation > z threshold
ii = find(abs(activation) > z_threshold);

x = mod(FMRI.idx(ii),FMRI.dime_x);
y = mod(floor(FMRI.idx(ii)/FMRI.dime_x),FMRI.dime_y);
z = floor(FMRI.idx(ii)/FMRI.dime_x/FMRI.dime_y);

d = [x y z];  
dd = pdist(d,dist_method);
%mdist = zeros(length(ii),length(ii));
%k=1;
%for i=1:length(ii)-1,
%  for j=(i+1):length(ii),
%    mdist(i,j) = dd(k);
%    k = k+1;
%  end
%end

%mdist = mdist + mdist';
%min_dist = zeros(1,length(ii));
%for i=1:length(ii),
%  temp = mdist(i,:);
%  temp(i) =[];
%  min_dist(i) = min(temp);
%end

% create the gamma fit to evaluate the distribution of compactness
[phat,pci]=gamfit(dd);
[n,x]=hist(dd,100);
n = n/length(dd); % normalize the distribution
deltax = min(x):(max(x)-min(x))/100:max(x);
y = gampdf(deltax,phat(1),phat(2));
figure
bar(x,n);
hold on
plot(deltax,y*max(n)/max(y),'r');
title(['Component ' num2str(component_no)]);
str = sprintf('gamma(%5.3f, %5.3f)',phat(1),phat(2));
a = axis;
tx = text(0.5*(a(2)+a(1)),0.9*(a(4)+a(3)),str);
set(tx,'fontsize',14,'color','r');
